@@ -152,6 +152,7 @@ async def _inplace_change(filename, old_string, new_string):
     writing_file.close()
 
 async def _append_line(filename, line):
+    print(filename, line)
     append_file = open(filename, "a")
     append_file.write(line)
     append_file.close()
@@ -208,6 +209,9 @@ class TaskDefs(dict):
 
             if 'inject' in obj:
                 self.run_vars['inject'] = obj['inject']
+            
+            if 'append' in obj:
+                self.run_vars['append'] = obj['append']
 
             if 'loop' in obj:
                 if isinstance(obj['loop'], int):
@@ -260,6 +264,11 @@ class Task(object):
         except AttributeError:
             pass
 
+    def update(self, vars):
+        #Terminate the task's process
+        self.vars = vars
+        self.cmd = self.cmd.format(**self.vars)
+
     #ADD ENV VAR here.
     async def run(self, args=None):
         rando = random_generator()
@@ -338,6 +347,10 @@ class TaskList(object):
         to_str.extend(["\t{}".format(task) for task in self.tasks])
         return "\n".join(to_str)
 
+    def append(self, task):
+        #Print available tasks and exit
+        tasks.append(task)
+
 class SequentialTaskList(TaskList):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -380,8 +393,6 @@ class SequentialTaskList(TaskList):
 #                    if isinstance(run_task, PythonTask):
 #                        pprint(vars(run_task))
                     if isinstance(run_task, Task):
-                        print(self.vars)
-                        pprint(vars(run_task))
                         run_task.cmd = run_task.cmd.format(**self.vars)
                     if self.kill:
                         break
@@ -398,8 +409,8 @@ class SequentialTaskList(TaskList):
         if 'append' in self.vars:
             if isinstance(self.vars['append'], list):
                 for line in self.vars['append']:
-                    line = await env_ject(line[1])
-                    await _append_line(line[0], line.format(**self.vars))
+                    clean = await env_ject(line[1])
+                    await _append_line(line[0], clean.format(**self.vars))
 
 
     def terminate(self):
@@ -411,14 +422,15 @@ class SequentialTaskList(TaskList):
 
 class AsyncTaskList(TaskList):
     async def run(self, args=None):
-        runtasks = {}
+        runtasks = list
         count = 0
         if args:
             error("Additional arguments not valid for Async tasks")
-#        while eval(self.wloop):
-#            count += 1 
-#            for i, task in enumerate(self.tasks):
-#                runtasks.append(task.cmd.format(**self.vars))
+        while eval(self.wloop):
+            count += 1 
+            for i, task in enumerate(self.tasks):
+                task.update(self.vars)
+                
         # Loop Time
 #        os.chdir(self.vars['dir'])
         await asyncio.wait(
